Campeonato Juizforano 2007 Juiz de Fora, Brazil December 16th 2007 23 players Pedro Paulo de Sousa Mendes (Pepê) Deck Name: Imbued at Last Description: The deck's goal is to setup as fast as you can by depleting your library and to use Unity/Anthelios to cycle back whatever master you need the most at the time. It was enough. I never needed more than this. Heart is no good when it shows up late, but this is a small price to pay when compared to how good it is when I draw it early (it was decisive in the final table). I only packed the extremely necessary events, so I wouldn't draw any extra table hate, and was lucky enough to put all 3 in play in every game. The decks runs wonderfully with those 3 on the table. Crypt (12 cards, min=14, max=20, avg=4.42) ------------------------------------------ 4x Travis "Traveler72" Miller 5 def mar Martyr:4 3x Jennie "Cassie247" Orne 5 inn jud vis Visionary:4 2x Paul "Sixofswords29" Moreton 4 def vis Visionary:4 2x François "Warden" Loehr 3 def jud Judge:4 1x Jack "Hannibal137" Harmon 4 def jud Defender:4 Library (60 cards) Master (25; 1 trifle) 2x Angel of Berlin 1x Barrens, The 1x Church of Vindicated Faith, The 1x Direct Intervention -- saved me a lot of times, unfortunately I couldn't pack more than one. 1x Fortschritt Library 6x Memories of Mortality 1x Millicent Smith, Puritan Vampire Hunter -- no comments needed. 3x Parthenon, The 1x Rötschreck 4x Slaughterhouse, The -- useful either to speed deck depletion or to trade for something useful under Anthelios. 1x Smiling Jack, The Anarch -- crucial contest in the final table. 1x Tension in the Ranks 1x Unity 1x Wash -- not as effective as I expected, but also not a hassle because it's trifle. Conviction (14) 4x React with Conviction 5x Second Sight 5x Strike with Conviction Action (1) 1x Aranthebes, The Immortal Ally (3) 1x Carlton Van Wyk 1x Ossian 1x Wendell Delburton Equipment (3) 1x Crusader Sword, The 1x Heart of Nizchetus 1x Ivory Bow Power (8) 2x Champion 2x Discern 1x Rejuvenate 3x Vigilance -- I started to win a game when I had those three in play. Reaction (3) 3x Determine Event (3) 1x Anthelios, The Red Star 1x Edge Explosion 1x Unmasking, The